@@ -62,6 +62,8 @@ nimbleOrRfunctionNames <- c('[',
                             'var',
                             'max',
                             'min',
+                            'pmin',
+                            'pmax',
                             'prod',
                             'asRow',
                             'asCol',
